<?php

define('SM_PATH', '../../');

function squirrelmail_plugin_init_vkeyboard()
{
    global $squirrelmail_plugin_hooks;

    $squirrelmail_plugin_hooks['login_top']['vkeyboard'] =
    'plugin_vkeyboard_top';
    $squirrelmail_plugin_hooks['login_form']['vkeyboard'] =
    'plugin_vkeyboard_form';
}

function plugin_vkeyboard_top()
{
    echo '<SCRIPT src="../plugins/vkeyboard/vkeyboard.js" type="text/javascr' .
         'ipt"></SCRIPT>';
}

function plugin_vkeyboard_form()
{
    include_once(SM_PATH . 'plugins/vkeyboard/config.php');
    global $password_form_name;

    if($msg_font_size == 'small')
       echo '<P style="text-align: center; font-size: x-small">';
    else
       echo '<P style="text-align: center">';

    if($display_msg == 'yes')
       echo 'Are you using a public computer?<BR>Enter your password with the ';
    if($link_type == 'text')
       echo '<A href="#" onclick="openwindow(\'' . $password_form_name .
            '\')">virtual keyboard</A>';
    else
       echo '<INPUT type="button" value="Keyboard" onclick="openwindow(\'' .
            $password_form_name . '\')">';
}

?>
